"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.addCustomRouteToAdminUi = void 0;
const j = __importStar(require("jscodeshift"));
const insertSpecifierImport_1 = require("../jsCodeShift/insertSpecifierImport");
const parseTs_1 = require("../../../../util/parseTs");
const getAdminUiTagChildren_1 = require("./getAdminUiTagChildren");
const composeImportForAppTsx_1 = require("./composeImportForAppTsx");
const TAG_NAME_CUSTOM_ROUTES = "CustomRoutes";
/**
 * Add Route with component to app. If Route with the same component name in Route path prop already exist - do nothing.
 * Example of added line `<Route path="/BlankComponent" element={<BlankComponent />} />`;
 *
 * @param appTsxInput text version of the file which will be changed
 * @param componentName name of added component
 * @param componentImportPath dir path where placed component
 * @param route routing path to component
 * @returns changed version of the file
 */
function addCustomRouteToAdminUi(appTsxInput, componentName, componentImportPath, route) {
    const appAST = (0, parseTs_1.parseTs)(appTsxInput);
    const adminUi = appAST.findJSXElements("AdminUI");
    const children = (0, getAdminUiTagChildren_1.getAdminUiTagChildren)(adminUi);
    // try to find CustomRoutes tag
    let customRoutes = children
        .find(el => j.JSXElement.check(el)
        && j.JSXIdentifier.check(el.openingElement.name)
        && el.openingElement.name.name === TAG_NAME_CUSTOM_ROUTES);
    // add CustomRoutes tag if not found
    if (customRoutes == null) {
        customRoutes = j.jsxElement(j.jsxOpeningElement(j.jsxIdentifier(TAG_NAME_CUSTOM_ROUTES)), j.jsxClosingElement(j.jsxIdentifier(TAG_NAME_CUSTOM_ROUTES)));
        children.push(customRoutes);
    }
    // try to find already existed <Route path="/BlankComponent" element={<BlankComponent />} /> tag in AdminUI
    const routeItem = customRoutes.children
        ?.filter(el => el.type === j.JSXElement.toString())
        .find(el => {
        if (!j.JSXElement.check(el) || !j.JSXIdentifier.check(el.openingElement.name)) {
            return false;
        }
        return el.openingElement.name.name === "Route"
            && el.openingElement.attributes?.some(attr => j.JSXAttribute.check(attr)
                && attr.name.name === "element"
                && j.JSXExpressionContainer.check(attr.value)
                && j.JSXElement.check(attr.value.expression)
                && j.JSXIdentifier.check(attr.value.expression.openingElement.name)
                && attr.value.expression.openingElement.name.name === componentName);
    });
    if (routeItem == null) {
        //todo modify
        const element = `<RouteSecured name="${componentName}"><${componentName} /></RouteSecured>`;
        const routeTag = `<Route path="${route}" element={${element}} />`;
        customRoutes.children?.push(j.stringLiteral(routeTag));
        (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, "RouteSecured", "../core/security/components/RouteSecured");
        console.log(`addCustomRouteToAdminUi: adding route '${route}' to AdminUI tag`);
    }
    else {
        console.log(`addCustomRouteToAdminUi: skip adding Route to app, Route ${componentName} already exist`);
    }
    const importPath = (0, composeImportForAppTsx_1.composeImportForAppTsx)(componentImportPath, componentName);
    (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, componentName, importPath);
    (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, 'Route', 'react-router');
    (0, insertSpecifierImport_1.insertSpecifierImport)(appAST, 'CustomRoutes', 'react-admin');
    return appAST.toSource();
}
exports.addCustomRouteToAdminUi = addCustomRouteToAdminUi;
//# sourceMappingURL=addCustomRouteToAdminUi.js.map