"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const addCustomRouteToAdminUi_1 = require("./addCustomRouteToAdminUi");
const chai_1 = __importStar(require("chai"));
const chai_string_1 = __importDefault(require("chai-string"));
chai_1.default.use(chai_string_1.default);
describe("addCustomRouteToAdminUi", () => {
    const route = '/route';
    const APP_TSX_INPUT_MIN = `
import { AdminContext, AdminUI} from "react-admin";
import { AdminLayout } from "./AdminLayout";

export const App = () => {
  return (
    <AdminContext>
        <AdminUI layout={AdminLayout}>
        </AdminUI>
    </AdminContext>
  );
};`;
    const APP_TSX_INPUT_WITHOUT_CUSTOM_ROUTERS = `
import { DevSupport } from "@react-buddy/ide-toolbox";
import { AdminContext, AdminUI, Resource } from "react-admin";
import { authProvider } from "../authProvider";
import { dataProvider } from "../dataProvider/graphqlDataProvider";
import { ComponentPreviews, useInitial } from "../dev";
import { i18nProvider } from "../i18nProvider";
import { AdminLayout } from "./AdminLayout";
import { PetList } from "./screens/pet/PetList";
import {PetCreateAdvanced} from "./screens/pet/PetCreateAdvanced";
import {PetEditAdvanced} from "./screens/pet/PetEditAdvanced";

export const App = () => {
  return (
    <AdminContext
      dataProvider={dataProvider}
      authProvider={authProvider}
      i18nProvider={i18nProvider}
    >
      <DevSupport ComponentPreviews={ComponentPreviews} useInitialHook={useInitial}>
        <AdminUI layout={AdminLayout}>
          <Resource
            name="PetDTO"
            options={{ label: "Pet" }}
            list={PetList}
            create={PetCreateAdvanced}
            edit={PetEditAdvanced}
          />
        </AdminUI>
      </DevSupport>
    </AdminContext>
  );
};`;
    const APP_TSX_INPUT_WITH_CUSTOM_ROUTERS = `
import { DevSupport } from "@react-buddy/ide-toolbox";
import { AdminContext, AdminUI, Resource } from "react-admin";
import { authProvider } from "../authProvider";
import { dataProvider } from "../dataProvider/graphqlDataProvider";
import { ComponentPreviews, useInitial } from "../dev";
import { i18nProvider } from "../i18nProvider";
import { AdminLayout } from "./AdminLayout";
import { PetList } from "./screens/pet/PetList";
import {PetCreateAdvanced} from "./screens/pet/PetCreateAdvanced";
import {PetEditAdvanced} from "./screens/pet/PetEditAdvanced";
import {OldComponent} from "./screens/added/old-import/OldComponent";

export const App = () => {
  return (
    <AdminContext
      dataProvider={dataProvider}
      authProvider={authProvider}
      i18nProvider={i18nProvider}
    >
      <DevSupport ComponentPreviews={ComponentPreviews} useInitialHook={useInitial}>
        <AdminUI layout={AdminLayout}>
          <Resource
            name="PetDTO"
            options={{ label: "Pet" }}
            list={PetList}
            create={PetCreateAdvanced}
            edit={PetEditAdvanced}
          />
          <CustomRoutes>
            <Route path="/route" element={<OldComponent />} />
          </CustomRoutes>
        </AdminUI>
      </DevSupport>
    </AdminContext>
  );
};`;
    const customRouteElement = `<RouteSecured name="NewComponent"><NewComponent /></RouteSecured>`;
    const screenImport = './screens/added/new-import';
    it("should create CustomRoutes tag with inserted Route tag, add 'Route' import and add 'CustomRoutes' import", function () {
        const res = (0, addCustomRouteToAdminUi_1.addCustomRouteToAdminUi)(APP_TSX_INPUT_MIN, "NewComponent", screenImport, route);
        (0, chai_1.expect)(res).to.containIgnoreSpaces(`
    <CustomRoutes>
      <Route path="/route" element={${customRouteElement}} />
    </CustomRoutes>`);
        (0, chai_1.expect)(res).to.contain(`import { NewComponent } from "../screens/added/new-import/NewComponent";`);
        (0, chai_1.expect)(res).to.contain(`import { AdminContext, AdminUI, CustomRoutes } from "react-admin";`);
        (0, chai_1.expect)(res).to.contain(`import { Route } from "react-router";`);
    });
    it("should create CustomRoutes tag with inserted Route tag if CustomRoutes not found", function () {
        const res = (0, addCustomRouteToAdminUi_1.addCustomRouteToAdminUi)(APP_TSX_INPUT_WITHOUT_CUSTOM_ROUTERS, "NewComponent", screenImport, route);
        (0, chai_1.expect)(res).to.containIgnoreSpaces(`
    <CustomRoutes>
      <Route path="/route" element={${customRouteElement}} />
    </CustomRoutes>`);
        (0, chai_1.expect)(res).to.contain(`import { NewComponent } from "../screens/added/new-import/NewComponent";`);
    });
    it("should insert Route tag to existing CustomRoutes tag", function () {
        const res = (0, addCustomRouteToAdminUi_1.addCustomRouteToAdminUi)(APP_TSX_INPUT_WITH_CUSTOM_ROUTERS, "NewComponent", screenImport, route);
        (0, chai_1.expect)(res).to.containIgnoreSpaces(`<Route path="/route" element={${customRouteElement}} />`);
        (0, chai_1.expect)(res).to.contain(`import { NewComponent } from "../screens/added/new-import/NewComponent";`);
    });
});
//# sourceMappingURL=addCustomRouteToAdminUi.test.js.map