"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const addScreenToAdminUi_1 = require("./addScreenToAdminUi");
const chai_1 = __importStar(require("chai"));
const chai_string_1 = __importDefault(require("chai-string"));
chai_1.default.use(chai_string_1.default);
describe("addScreenToAdminUi", () => {
    const APP_TSX_INPUT_MIN = `
import { AdminContext, AdminUI} from "react-admin";
import { AdminLayout } from "./AdminLayout";

export const App = () => {
  return (
    <AdminContext>
        <AdminUI layout={AdminLayout}>
        </AdminUI>
    </AdminContext>
  );
};`;
    const APP_TSX_INPUT = `
import { DevSupport } from "@react-buddy/ide-toolbox";
import { AdminContext, AdminUI, Resource } from "react-admin";
import { authProvider } from "../authProvider";
import { dataProvider } from "../dataProvider/graphqlDataProvider";
import { ComponentPreviews, useInitial } from "../dev";
import { i18nProvider } from "../i18nProvider";
import { AdminLayout } from "./AdminLayout";
import { PetList } from "./screens/pet/PetList";
import {PetCreateAdvanced} from "./screens/pet/PetCreateAdvanced";
import {PetEditAdvanced} from "./screens/pet/PetEditAdvanced";

export const App = () => {
  return (
    <AdminContext
      dataProvider={dataProvider}
      authProvider={authProvider}
      i18nProvider={i18nProvider}
    >
      <DevSupport ComponentPreviews={ComponentPreviews} useInitialHook={useInitial}>
        <AdminUI layout={AdminLayout}>
          <ResourceSecured
            name="PetDTO"
            list={PetList}
            create={PetCreateAdvanced}
            edit={PetEditAdvanced}
          />
        </AdminUI>
      </DevSupport>
    </AdminContext>
  );
};`;
    const screenImport = './screens/added/new-import';
    it("should create resource tag, add 'Resource' import and add screen attribute", function () {
        const res = (0, addScreenToAdminUi_1.addScreenToAdminUi)(APP_TSX_INPUT_MIN, "NewEntityDTO", "NewEntityScreenUpdated", "create", screenImport);
        (0, chai_1.expect)(res).to.containIgnoreSpaces(`
    <ResourceSecured
      name="NewEntityDTO"
      create={NewEntityScreenUpdated} 
      recordRepresentation={getNewEntityDtoRecordRepresentation}
    />`);
        (0, chai_1.expect)(res).to.contain(`import { NewEntityScreenUpdated } from "../screens/added/new-import/NewEntityScreenUpdated";`);
        (0, chai_1.expect)(res).to.contain(`import { getNewEntityDtoRecordRepresentation } from "../core/record-representation/getNewEntityDtoRecordRepresentation";`);
        (0, chai_1.expect)(res).to.contain(`import { ResourceSecured } from "../core/security/components/ResourceSecured";`);
    });
    it("should create resource tag and add screen attribute", function () {
        const res = (0, addScreenToAdminUi_1.addScreenToAdminUi)(APP_TSX_INPUT, "NewEntityDTO", "NewEntityScreenUpdated", "create", screenImport);
        (0, chai_1.expect)(res).to.containIgnoreSpaces(`
    <ResourceSecured
        name="NewEntityDTO"
        create={NewEntityScreenUpdated} 
        recordRepresentation={getNewEntityDtoRecordRepresentation} />
    `);
        (0, chai_1.expect)(res).to.contain(`import { NewEntityScreenUpdated } from "../screens/added/new-import/NewEntityScreenUpdated";`);
    });
    it("should add screen attribute in existed resource tag", function () {
        const res = (0, addScreenToAdminUi_1.addScreenToAdminUi)(APP_TSX_INPUT, "PetDTO", "NewEntityScreenUpdated", "show", screenImport);
        (0, chai_1.expect)(res).to.containIgnoreSpaces(`
      <ResourceSecured
        name="PetDTO"
        list={PetList}
        create={PetCreateAdvanced}
        edit={PetEditAdvanced}
        show={NewEntityScreenUpdated} />
    `);
        (0, chai_1.expect)(res).to.contain(`import { NewEntityScreenUpdated } from "../screens/added/new-import/NewEntityScreenUpdated";`);
    });
    it("should update screen attribute value in existed resource tag", function () {
        const res = (0, addScreenToAdminUi_1.addScreenToAdminUi)(APP_TSX_INPUT, "PetDTO", "NewEntityScreenUpdated", "create", screenImport);
        (0, chai_1.expect)(res).to.containIgnoreSpaces(`
      <ResourceSecured
        name="PetDTO"
        list={PetList}
        create={NewEntityScreenUpdated}
        edit={PetEditAdvanced} />
    `);
        (0, chai_1.expect)(res).to.contain(`import { NewEntityScreenUpdated } from "../screens/added/new-import/NewEntityScreenUpdated";`);
    });
    it("should fail if there is more than one Menu tag in input", function () {
        // TODO
    });
    // TODO - empty/incorrect input e.t.c
});
//# sourceMappingURL=addScreenToAdminUi.test.js.map