"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.writeEntityEditor = void 0;
const path_1 = __importDefault(require("path"));
const mvp_1 = require("../../../building-blocks/stages/writing/pieces/mvp/mvp");
const writeResourceToMenu_1 = require("../common/writeResourceToMenu");
const writeScreenToAdminUi_1 = require("../common/writeScreenToAdminUi");
const generatorPaths_1 = require("../common/generatorPaths");
const writeRecordRepresentationFunctionsForRelations_1 = require("../common/recordRepresentation/writeRecordRepresentationFunctionsForRelations");
const writeRecordRepresentationFunction_1 = require("../common/recordRepresentation/writeRecordRepresentationFunction");
const mergeI18nMessagesWithLocaleFile_1 = require("../common/i18n/mergeI18nMessagesWithLocaleFile");
async function writeEntityEditor(templateModel, gen) {
    const { relDirShift, entityName, i18nMessages } = templateModel;
    await (0, mvp_1.writeAmplicodeComponent)({ componentName: templateModel.createComponentName, ...templateModel }, gen, path_1.default.join(__dirname, 'template', 'CreateAdvanced.tsx.ejs'), false, false, !templateModel.skipTestGeneration);
    await (0, mvp_1.writeAmplicodeComponent)({ componentName: templateModel.editComponentName, ...templateModel }, gen, path_1.default.join(__dirname, 'template', 'EditAdvanced.tsx.ejs'), false, false, !templateModel.skipTestGeneration);
    const screenPaths = (0, generatorPaths_1.deriveScreenPaths)(gen.destinationRoot(), relDirShift);
    // Add menu item
    (0, writeResourceToMenu_1.writeResourceToMenu)(gen, screenPaths.srcPath, entityName);
    // Add screens to <AdminUI> in App.tsx
    (0, writeScreenToAdminUi_1.writeScreenToAdminUi)(gen, screenPaths, entityName, templateModel.createComponentName, "create");
    (0, writeScreenToAdminUi_1.writeScreenToAdminUi)(gen, screenPaths, entityName, templateModel.editComponentName, "edit");
    await (0, writeRecordRepresentationFunction_1.writeRecordRepresentationFunction)({
        gen: gen,
        entityName: templateModel.entityName,
        attributes: templateModel.allAttributes,
        dirShift: templateModel.relDirShift
    });
    await (0, writeRecordRepresentationFunctionsForRelations_1.writeRecordRepresentationFunctionsForRelations)(gen, templateModel.attributes, templateModel.relDirShift);
    await (0, mergeI18nMessagesWithLocaleFile_1.mergeI18nMessagesWithLocaleFile)(screenPaths.localeMessagesPath, 'en', i18nMessages);
}
exports.writeEntityEditor = writeEntityEditor;
//# sourceMappingURL=write.js.map